@@ -33,8 +33,8 @@ PdfParser::PdfParser() :streamhandler(0), texthandler(0) {
 
 StreamStatus
 PdfParser::read(int32_t min, int32_t max) {
-    int32_t off = pos-start;
-    int32_t d = stream->position() - objdefstart;
+    int32_t off = (int32_t)(pos-start);
+    int32_t d = (int32_t)(stream->position() - objdefstart);
     min += d;
     if (max > 0) max += d;
     stream->reset(objdefstart);
@@ -109,12 +109,10 @@ PdfParser::skipNotFromString(const char*str, int32_t n) {
 }
 StreamStatus
 PdfParser::skipKeyword(const char* str, int32_t len) {
-    if (end - pos < len) {
-        StreamStatus s;
-        if ((s = read(len, 0)) != Ok) {
+    StreamStatus s = checkForData(len);
+    if (s != Ok) {
             m_error.assign("Premature end of stream.");
             return Error;
-        }
     }
 //    printf("skipKeyword %s '%.*s'\n", str, (len>end-pos)?end-pos:len, pos);
     if (strncmp(pos, str, len) != 0) {
@@ -185,13 +183,15 @@ PdfParser::parseNumber() {
     StreamStatus n = skipDigits();
     if (n != Ok) return n;
     if (pos < end && *pos == '.') {
+        // a '.' so this is a float
         pos++;
         n = skipDigits();
         const char *s = start + p;
         lastNumber = strtod(s, 0);
     } else {
+        // no dot so this is a long
         const char *s = start + p;
-        lastNumber = strtol(s, 0, 10);
+        lastNumber = (double)strtol(s, 0, 10);
     }
     // parse a number
     lastObject = &lastNumber;
@@ -424,8 +424,8 @@ PdfParser::parseNull() {
 StreamStatus
 PdfParser::parseObjectStreamObject() {
 //    printf("parseObjectStreamObject %.*s\n", (5>end-pos)?end-pos:5, pos);
-    StreamStatus r = read(2, 0);
-    if (r == Error) return r;
+    StreamStatus r = checkForData(2);
+    if (r != Ok) return r;
 
     char ch = *pos;
     if (ch == 't' || ch == 'f') {
@@ -455,7 +455,7 @@ PdfParser::parseObjectStreamObject() {
 }
 StreamStatus
 PdfParser::parseContentStreamObject() {
-    StreamStatus r = read(2, 0);
+    StreamStatus r = checkForData(2);
     if (r != Ok) return r;
 //    fprintf(stderr, "parseContentStreamObject %.*s\n",
 //        (5>end-pos)?end-pos:5, pos);
